import React, { createContext, useContext, useEffect, useReducer } from "react";
import DefaultLoadingScreen from "./components/DefaultLoadingScreen";
const DefaultAuthContext = {
    state: {
        isLoading: false,
        isSignedIn: false,
        userData: null
    },
    dispatch: () => { },
    signOut: () => { },
    signIn: () => { },
    isLoaded: () => { },
    isLoading: () => { },
};
export const AuthContext = createContext(DefaultAuthContext);
export function useAuth() {
    return useContext(AuthContext);
}
function reducer(prevState, action) {
    switch (action.type) {
        case "SIGN_IN":
            return Object.assign(Object.assign({}, prevState), { isSignedIn: true, isLoading: false, userData: action.userData });
        case "SIGN_OUT":
            return Object.assign(Object.assign({}, prevState), { isSignedIn: false, isLoading: false, userData: null });
        case "LOADED":
            return Object.assign(Object.assign({}, prevState), { isLoading: false });
        case "IS_LOADING":
            return Object.assign(Object.assign({}, prevState), { isLoading: true });
        default:
            return Object.assign({}, prevState);
    }
}
export function Auth({ AutoLoginComponent, AfterSignInComponent, BeforeSignInComponent, autoLogin, LoadingScreen = React.createElement(DefaultLoadingScreen, null), isLoadingInitially = false, splashScreenTime = 3000 }) {
    const intialstate = {
        isLoading: isLoadingInitially,
        isSignedIn: false,
        userData: null
    };
    const [state, dispatch] = useReducer(reducer, intialstate);
    const signIn = (userData) => {
        dispatch({ type: "SIGN_IN", userData: userData });
    };
    const signOut = () => {
        dispatch({ type: "SIGN_OUT" });
    };
    const isLoaded = () => {
        dispatch({ type: "LOADED" });
    };
    const isLoading = () => {
        dispatch({ type: "IS_LOADING" });
    };
    useEffect(() => {
        setTimeout(isLoaded, splashScreenTime);
    }, []);
    return state.isLoading ? (React.createElement(React.Fragment, null, LoadingScreen)) : (React.createElement(AuthContext.Provider, { value: { state, dispatch, signOut, signIn, isLoaded, isLoading } },
        React.createElement(React.Fragment, null,
            autoLogin && AutoLoginComponent,
            state.isSignedIn ? React.createElement(React.Fragment, null, AfterSignInComponent) : React.createElement(React.Fragment, null, BeforeSignInComponent))));
}
//# sourceMappingURL=Auth.js.map