var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { useCallback, useEffect, useState } from "react";
import axios from "axios";
/**
 * General Hook structure for API Call.
 * @param defaultCall
 * @param APIUrl
 * @param apiReq
 * @param props
 * @param defaultValue
 */
export const useGenericAPIHook = (_a) => {
    var { defaultCall = false, APIUrl, apiReq, defaultValue } = _a, props = __rest(_a, ["defaultCall", "APIUrl", "apiReq", "defaultValue"]);
    const [state, setState] = useState(defaultValue);
    const [loading, setLoading] = useState(false);
    const [errors, setErrors] = useState(null);
    const fetch = useCallback((formData) => new Promise(((resolve) => __awaiter(void 0, void 0, void 0, function* () {
        var _b;
        setLoading(true);
        try {
            const { data } = yield axios.post(APIUrl, Object.assign(Object.assign({}, apiReq), formData));
            const formattedData = ((_b = props.formatResponse) === null || _b === void 0 ? void 0 : _b.call(props, data)) || data;
            setState(formattedData);
            resolve(formattedData);
        }
        catch (e) {
            setErrors([JSON.stringify(e)]);
            resolve(undefined);
        }
        setLoading(false);
    }))), [] // eslint-disable-line
    );
    useEffect(() => {
        if (defaultCall) {
            fetch();
        }
    }, []); // eslint-disable-line
    return { data: state, fetch, loading, errors };
};
//# sourceMappingURL=useGenericAPIHook.js.map